"""This file was generated by xsdata, v25.4, on 2025-05-13 09:06:38

Generator: PydanticGenerator
See: https://xsdata.readthedocs.io/
"""

from pyosis.generated.osis_core_2_1_1 import (
    AbbrCt,
    ACt,
    ActorCt,
    Calendar,
    CaptionCt,
    CastGroupCt,
    CastItemCt,
    CastListCt,
    CatchWordCt,
    CellCt,
    ChapterCt,
    CloserCt,
    ContributorCt,
    CorpusHeaderCt,
    CoverageCt,
    CreatorCt,
    DateCt,
    DescriptionCt,
    DivCt,
    DivineNameCt,
    FigureCt,
    ForeignCt,
    FormatCt,
    HeadCt,
    HeaderCt,
    HiCt,
    IdentifierCt,
    IndexCt,
    InscriptionCt,
    ItemCt,
    LabelCt,
    LanguageCt,
    LbCt,
    LCt,
    LgCt,
    ListCt,
    MentionedCt,
    Milestoneable,
    MilestoneCt,
    MilestoneEndCt,
    MilestoneSe,
    MilestoneStartCt,
    NameCt,
    NoteCt,
    Osis,
    OsisAnnotation,
    OsisCellAlign,
    OsisChanges,
    OsisCorpusCt,
    OsisCt,
    OsisDescription,
    OsisDivs,
    OsisEvents,
    OsisHi,
    OsisIdentifier,
    OsisLanguage,
    OsisLanguageUsage,
    OsisLine,
    OsisMilestonePt,
    OsisNames,
    OsisNotes,
    OsisPlacementNote,
    OsisPlacementTitle,
    OsisQuotes,
    OsisRdg,
    OsisReferences,
    OsisRoles,
    OsisSegs,
    OsisSubjects,
    OsisTextCt,
    OsisTitles,
    OsisType,
    PCt,
    PublisherCt,
    QCt,
    RdgCt,
    RdgGrpCt,
    ReferenceCt,
    RefSystemCt,
    RelationCt,
    RevisionDescCt,
    RightsCt,
    RoleCt,
    RoleDescCt,
    RowCt,
    SaluteCt,
    ScopeCt,
    SegCt,
    SignedCt,
    SourceCt,
    SpeakerCt,
    SpeechCt,
    SubjectCt,
    TableCt,
    TableRole,
    TeiHeaderCt,
    TitleCt,
    TitlePageCt,
    TransChangeCt,
    TypeCt,
    VerseCt,
    WCt,
    WorkCt,
    WorkPrefixCt,
)
from pyosis.generated.xml import (
    LangValue,
    SpaceValue,
)

__all__ = [
    "ACt",
    "AbbrCt",
    "ActorCt",
    "Calendar",
    "CaptionCt",
    "CastGroupCt",
    "CastItemCt",
    "CastListCt",
    "CatchWordCt",
    "CellCt",
    "ChapterCt",
    "CloserCt",
    "ContributorCt",
    "CorpusHeaderCt",
    "CoverageCt",
    "CreatorCt",
    "DateCt",
    "DescriptionCt",
    "DivCt",
    "DivineNameCt",
    "FigureCt",
    "ForeignCt",
    "FormatCt",
    "HeadCt",
    "HeaderCt",
    "HiCt",
    "IdentifierCt",
    "IndexCt",
    "InscriptionCt",
    "ItemCt",
    "LCt",
    "LabelCt",
    "LangValue",
    "LanguageCt",
    "LbCt",
    "LgCt",
    "ListCt",
    "MentionedCt",
    "MilestoneCt",
    "MilestoneEndCt",
    "MilestoneSe",
    "MilestoneStartCt",
    "Milestoneable",
    "NameCt",
    "NoteCt",
    "Osis",
    "OsisAnnotation",
    "OsisCellAlign",
    "OsisChanges",
    "OsisCorpusCt",
    "OsisCt",
    "OsisDescription",
    "OsisDivs",
    "OsisEvents",
    "OsisHi",
    "OsisIdentifier",
    "OsisLanguage",
    "OsisLanguageUsage",
    "OsisLine",
    "OsisMilestonePt",
    "OsisNames",
    "OsisNotes",
    "OsisPlacementNote",
    "OsisPlacementTitle",
    "OsisQuotes",
    "OsisRdg",
    "OsisReferences",
    "OsisRoles",
    "OsisSegs",
    "OsisSubjects",
    "OsisTextCt",
    "OsisTitles",
    "OsisType",
    "PCt",
    "PublisherCt",
    "QCt",
    "RdgCt",
    "RdgGrpCt",
    "RefSystemCt",
    "ReferenceCt",
    "RelationCt",
    "RevisionDescCt",
    "RightsCt",
    "RoleCt",
    "RoleDescCt",
    "RowCt",
    "SaluteCt",
    "ScopeCt",
    "SegCt",
    "SignedCt",
    "SourceCt",
    "SpaceValue",
    "SpeakerCt",
    "SpeechCt",
    "SubjectCt",
    "TableCt",
    "TableRole",
    "TeiHeaderCt",
    "TitleCt",
    "TitlePageCt",
    "TransChangeCt",
    "TypeCt",
    "VerseCt",
    "WCt",
    "WorkCt",
    "WorkPrefixCt",
]



"""This file was generated by xsdata, v25.4, on 2025-05-13 09:06:38

Generator: PydanticGenerator
See: https://xsdata.readthedocs.io/
"""

from enum import Enum

__NAMESPACE__ = "http://www.w3.org/XML/1998/namespace"


class LangValue(Enum):
    VALUE = ""


class SpaceValue(Enum):
    DEFAULT = "default"
    PRESERVE = "preserve"



"""Wrapper class for OSIS objects for easy serialization."""

import dataclasses

from typing_extensions import Self
from xsdata.formats.dataclass.serializers.config import SerializerConfig
from xsdata_pydantic.bindings import XmlContext, XmlParser, XmlSerializer

import pyosis.generated
import pyosis.generated.osis_core_2_1_1

CONTEXT = XmlContext()
CONFIG = SerializerConfig(indent="  ")
PARSER = XmlParser(context=CONTEXT)
SERIALIZER = XmlSerializer(context=CONTEXT, config=CONFIG)


@dataclasses.dataclass
class OsisXML:
    """Wrapper class for OSIS objects for easy serialization."""

    osis: pyosis.generated.osis_core_2_1_1.Osis
    """OSIS object."""

    @classmethod
    def from_xml(cls, xml: str) -> Self:
        """Deserialize an XML string to an OSIS Object."""
        return cls(osis=PARSER.from_string(xml, pyosis.generated.Osis))

    def to_xml(self) -> str:
        """Serialize an OSIS object to an XML file."""
        return SERIALIZER.render(self.osis, ns_map={None: pyosis.generated.osis_core_2_1_1.__NAMESPACE__})



"""Python tools for serializing and using OSIS files."""

__version__ = "0.2.0"

# ruff: noqa: F403

from pyosis import generated as generated
from pyosis.generated import *
from pyosis.serialization import OsisXML as OsisXML



"""Generate the entire OSIS schema for `pyosis.generated`."""

import os
import pathlib
import subprocess
import sys


def generate() -> subprocess.CompletedProcess[str]:
    current_file_path = pathlib.Path(__file__)
    os.chdir(current_file_path.parent.parent)

    result = subprocess.run(
        [
            "xsdata",
            "generate",
            "--output",
            "pydantic",
            "--package",
            "pyosis.generated",
            "https://crosswire.org/osis/osisCore.2.1.1.xsd",
            "--include-header",
            "--max-line-length",
            "120",
            "--docstring-style",
            "Google",
        ],
        capture_output=True,
        text=True,
        check=True,
    )
    return result


if __name__ == "__main__":
    sys.exit(generate().returncode)



"""Test the Osis model classes."""

import hypothesis

import pyosis


@hypothesis.given(osis_model=...)
def test_roundtrip_serialization(osis_model: pyosis.OsisXML) -> None:
    """Test that an Osis model can be serialized and deserialized.

    Args:
        osis_model: An Osis model instance.
    """
    serialized = osis_model.to_xml()
    deserialized = pyosis.OsisXML.from_xml(serialized)
    assert osis_model == deserialized
